==> igniteui-react-charts-16.15.1.tgz: package/esm2015/lib/CommodityChannelIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { CommodityChannelIndexIndicatorStrategy } from "./CommodityChannelIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let CommodityChannelIndexIndicator = /*@__PURE__*/ (() => {
    class CommodityChannelIndexIndicator extends StrategyBasedIndicator {
        get_t4() {
            return new CommodityChannelIndexIndicatorStrategy();
        }
        get t4() {
            return this.get_t4();
        }
        get_uh() {
            return CommodityChannelIndexIndicator.$;
        }
        get uh() {
            return this.get_uh();
        }
        get up() {
            return typeGetValue(this.c(CommodityChannelIndexIndicator.uq));
        }
        set up(a) {
            this.h(CommodityChannelIndexIndicator.uq, a);
        }
        ua() {
            return this.up;
        }
        uj(a) {
            this.up = a;
        }
    }
    CommodityChannelIndexIndicator.$t = /*@__PURE__*/ markType(CommodityChannelIndexIndicator, 'CommodityChannelIndexIndicator', StrategyBasedIndicator.$);
    CommodityChannelIndexIndicator.uq = /*@__PURE__*/ StrategyBasedIndicator.um(20, CommodityChannelIndexIndicator.$);
    return CommodityChannelIndexIndicator;
})();

==> igniteui-react-charts-16.16.1.tgz: package/esm2015/lib/CommodityChannelIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { CommodityChannelIndexIndicatorStrategy } from "./CommodityChannelIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let CommodityChannelIndexIndicator = /*@__PURE__*/ (() => {
    class CommodityChannelIndexIndicator extends StrategyBasedIndicator {
        get_uh() {
            return new CommodityChannelIndexIndicatorStrategy();
        }
        get uh() {
            return this.get_uh();
        }
        get_uu() {
            return CommodityChannelIndexIndicator.$;
        }
        get uu() {
            return this.get_uu();
        }
        get u2() {
            return typeGetValue(this.c(CommodityChannelIndexIndicator.u3));
        }
        set u2(a) {
            this.h(CommodityChannelIndexIndicator.u3, a);
        }
        un() {
            return this.u2;
        }
        uw(a) {
            this.u2 = a;
        }
    }
    CommodityChannelIndexIndicator.$t = /*@__PURE__*/ markType(CommodityChannelIndexIndicator, 'CommodityChannelIndexIndicator', StrategyBasedIndicator.$);
    CommodityChannelIndexIndicator.u3 = /*@__PURE__*/ StrategyBasedIndicator.uz(20, CommodityChannelIndexIndicator.$);
    return CommodityChannelIndexIndicator;
})();
